"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai = require("chai");
// importing with ts method breaks compilation, use require
//tslint:disable
const chaiSubset = require('chai-subset');
//tslint:enable
chai.use(chaiSubset);
const expect = chai.expect;
//tslint:disable
const expectWithDeepMatch = expect;
/**
 * Expectations for chai based frameworks
 */
class ChaiExpectation {
    constructor(subject, message) {
        this.subject = subject;
        this.message = message;
    }
    notToBeEmpty() {
        expect(this.subject, this.message).not.to.be.empty;
    }
    toEqual(value) {
        expect(this.subject, this.message).to.equal(value);
    }
    toInclude(value) {
        expect(this.subject, this.message).to.include(value);
    }
    toBeTrue() {
        expect(this.subject, this.message).to.be.true;
    }
    /**
     * deeply compares an outgoing message with the expected messages that are considered valid for this test to pass.
     * It does a subset comparison, so as long as the expected message is a subset of one of the expected responses, this will pass
     *
     * @param outgoingMessage actual message that bot sends
     */
    toDeeplyInclude(outgoingMessage) {
        const expectedResponseCollectionAsIMessage = this.subject;
        // tslint:disable
        const expectWithDeepMatch = expect;
        // tslint:enable
        let matchExists = false;
        expectedResponseCollectionAsIMessage.forEach((expectedResponse) => {
            const exp = expect;
            if (matchExists) {
                return;
            }
            const clone = Object.assign({}, outgoingMessage);
            // ignore source event (not added to message until after sending)
            delete expectedResponse.source;
            // auto added by prompts, not needed
            delete outgoingMessage.inputHint;
            // always botbuilder
            delete expectedResponse.agent;
            try {
                expect(clone).to.containSubset(expectedResponse);
                matchExists = true;
            }
            catch (e) {
                // continue, no match found
            }
        });
        if (!matchExists) {
            expect.fail(null, null, `expected ${JSON.stringify(outgoingMessage)}\
            to be a subset of one of ${JSON.stringify(expectedResponseCollectionAsIMessage, null, 2)}`);
        }
    }
}
exports.ChaiExpectation = ChaiExpectation;
//# sourceMappingURL=ChaiExpectation.js.map